@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -11,7 +11,7 @@
 
 
 # Enthought library imports.
-from traits.api import Instance, on_trait_change
+from traits.api import Instance, observe, on_trait_change
 
 # Local imports.
 from .i_plugin_manager import IPluginManager
@@ -37,8 +37,10 @@ class PluginExtensionRegistry(ProviderExtensionRegistry):
 
     #### Trait change handlers ################################################
 
-    def _plugin_manager_changed(self, trait_name, old, new):
+    @observe("plugin_manager")
+    def _update_providers(self, event):
         """ Static trait change handler. """
+        old, new = event.old, event.new
 
         # In practise I can't see why you would ever want (or need) to change
         # the registry's plugin manager on the fly, but hey... Hence, 'old'
@@ -51,20 +53,14 @@ class PluginExtensionRegistry(ProviderExtensionRegistry):
             for plugin in new:
                 self.add_provider(plugin)
 
-        return
-
     @on_trait_change("plugin_manager:plugin_added")
     def _on_plugin_added(self, obj, trait_name, old, event):
         """ Dynamic trait change handler. """
 
         self.add_provider(event.plugin)
 
-        return
-
     @on_trait_change("plugin_manager:plugin_removed")
     def _on_plugin_removed(self, obj, trait_name, old, event):
         """ Dynamic trait change handler. """
 
         self.remove_provider(event.plugin)
-
-        return
