@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ An action that shows the 'About' dialog. """
 
@@ -19,13 +20,13 @@ class AboutAction(Action):
     #### 'Action' interface ###################################################
 
     # A longer description of the action.
-    description = 'Display information about the application'
+    description = "Display information about the application"
 
     # The action's name (displayed on menus/tool bar tools etc).
-    name = 'About'
+    name = "About"
 
     # A short description of the action used for tooltip text etc.
-    tooltip = 'Display information about the application'
+    tooltip = "Display information about the application"
 
     ###########################################################################
     # 'Action' interface.
@@ -35,7 +36,3 @@ class AboutAction(Action):
         """ Perform the action. """
 
         self.window.application.about()
-
-        return
-
-#### EOF ######################################################################
